@@ -1,5 +1,4 @@
 #!/usr/share/ucs-test/runner pytest-3 -s
-# -*- coding: utf-8 -*-
 ## desc: Test various functions in the UDM REST API
 ## tags: [udm,apptest]
 ## roles: [domaincontroller_master]
@@ -15,7 +14,7 @@ import pytest
 from univention.admin.rest.client import UDM as UDMClient, Forbidden, PreconditionFailed, Unauthorized
 from univention.config_registry import ConfigRegistry, handler_set
 from univention.lib.misc import custom_groupname
-from univention.testing.udm import UDM
+from univention.testing.udm import UDM, UCSTestUDM_CreateUDMObjectFailed
 from univention.testing.utils import UCSTestDomainAdminCredentials
 
 ucr = ConfigRegistry()
@@ -82,7 +81,7 @@ def test_etag_last_modified(udm):
 	# assert 'If-Unmodified-Since' in str(exc)
 
 
-@pytest.mark.parametrize('suffix', ['', u'ä'])
+@pytest.mark.parametrize('suffix', ['', 'ä'])
 def test_create_modify_move_remove(random_string, suffix, ucr):
 	if suffix:
 		handler_set(['directory/manager/web/modules/users/user/properties/username/syntax=string'])
@@ -118,7 +117,7 @@ def test_create_modify_move_remove(random_string, suffix, ucr):
 @pytest.mark.parametrize('name', [
 	'''a !"#$%&'"()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~z''',
 	'foo//bar',
-	u'foobär',
+	'foobär',
 ])
 def test_special_characters_in_dn(name):
 	with UDM() as udm:
@@ -128,3 +127,15 @@ def test_special_characters_in_dn(name):
 		obj = udm_client.get('container/cn').get(container)
 		print(obj)
 		assert obj
+
+
+@pytest.mark.parametrize('language,error_message', [
+	('en-US', 'The property gecos has an invalid value: Field must only contain ASCII characters!'),
+	('de-DE', 'Die Eigenschaft gecos hat einen ungültigen Wert: Der Wert darf nur ASCII Buchstaben enthalten!'),
+])
+def test_translation(language, error_message):
+	with UDM(language=language) as udm:
+		with pytest.raises(UCSTestUDM_CreateUDMObjectFailed) as exc:
+			userdn, user = udm.create_user(gecos='foobär')
+
+		assert error_message in str(exc.value)
