@@ -1,5 +1,4 @@
 #!/usr/share/ucs-test/runner /usr/share/ucs-test/selenium-pytest
-# -*- coding: utf-8 -*-
 ## desc: test self registration
 ## tags: [apptest]
 ## packages:
@@ -88,7 +87,7 @@ def get_registration_info(ucr):
 
 def _get_mail(mails, idx=-1):
 	assert mails.data, 'No mails have been captured in %s seconds' % (MAILS_TIMEOUT,)
-	assert idx < len(mails.data), 'Not enough mails have been captured to get mail of index: {}'.format(idx)
+	assert idx < len(mails.data), f'Not enough mails have been captured to get mail of index: {idx}'
 	mail = email.message_from_string(mails.data[idx].decode("utf-8"))
 	body = mail.get_payload(decode=True).decode("utf-8")
 	verification_links = []
