@@ -1,7 +1,9 @@
-# -*- coding: utf-8 -*-
 #
 # UCS test
 #
+# Like what you see? Join us!
+# https://www.univention.com/about-us/careers/vacancies/
+#
 # Copyright 2013-2022 Univention GmbH
 #
 # https://www.univention.de/
@@ -57,7 +59,7 @@ from univention.testing.decorators import WaitForNonzeroResultOrTimeout
 COMMASPACE = ', '
 
 
-class Mail(object):
+class Mail:
 
 	def __init__(self, timeout=10):
 		self.timeout = timeout
@@ -66,7 +68,7 @@ class Mail(object):
 		reply = ''
 		try:
 			buff_size = 1024
-			while(True):
+			while True:
 				part = s.recv(buff_size)
 				reply += part
 				if len(part) < buff_size:
@@ -180,7 +182,7 @@ class ImapMail(Mail):
 				break
 		assert separator is not None, 'Could not find parent folder.'
 		# create subfolder
-		subfolder_name = '{}{}{}'.format(parent, separator, child)
+		subfolder_name = f'{parent}{separator}{child}'
 		rv, data = self.connection.create(subfolder_name)
 		assert rv == "OK"
 		return subfolder_name
@@ -284,7 +286,7 @@ def restart_postfix():
 	cmd = ['/etc/init.d/postfix', 'restart']
 	try:
 		subprocess.Popen(cmd, stderr=open('/dev/null', 'w')).communicate()
-	except EnvironmentError as ex:
+	except OSError as ex:
 		print(ex, file=sys.stderr)
 
 
@@ -292,7 +294,7 @@ def reload_postfix():
 	cmd = ['/etc/init.d/postfix', 'force-reload']
 	try:
 		subprocess.Popen(cmd, stderr=open('/dev/null', 'w')).communicate()
-	except EnvironmentError as ex:
+	except OSError as ex:
 		print(ex, file=sys.stderr)
 
 
@@ -304,7 +306,7 @@ def reload_amavis_postfix():
 	):
 		try:
 			subprocess.Popen(cmd, stderr=open('/dev/null', 'w')).communicate()
-		except EnvironmentError as ex:
+		except OSError as ex:
 			print(ex, file=sys.stderr)
 
 
@@ -753,7 +755,7 @@ def check_sending_mail(
 	allowed=True,
 	local=True
 ):
-	token = 'The token is {}.'.format(time.time())
+	token = f'The token is {time.time()}.'
 	try:
 		ret_code = send_mail(
 			recipients=recipient_email,
